# [2.4.6](https://github.com/seriaati/enka-py/compare/v2.4.5..v2.4.6) - 2025-03-01

## Bug Fixes

- **(gi)** Fix stats missing names - ([21308e6](https://github.com/seriaati/enka-py/commit/21308e6f4ffbd2944e1c676db7b34ac6f1fde1f6))
- Update Field defaults to use default_factory for list fields - ([20ac398](https://github.com/seriaati/enka-py/commit/20ac398e9ca928e7a02cbaef23d508e6bbe17fd6))
- Change HSR text map data source - ([70b2ce5](https://github.com/seriaati/enka-py/commit/70b2ce59ff931a2c84bd5f86bac77ed07c918eb5))

## Miscellaneous Chores

- **(deps)** lock file maintenance ([#91](https://github.com/seriaati/enka-py/issues/91)) - ([6e83a1d](https://github.com/seriaati/enka-py/commit/6e83a1d7c6743df2a4917168905da1018e8f2280))
- **(deps)** lock file maintenance ([#92](https://github.com/seriaati/enka-py/issues/92)) - ([9787666](https://github.com/seriaati/enka-py/commit/97876660e54cc729d47400375fb2398b7f255839))

